#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include <QMainWindow>
#include <QStringList>
#include <QStandardItemModel>
#include <QGraphicsScene>
#include "quaditem.h"

namespace Ui {
class MainWindow;
}

class MainWindow : public QMainWindow
{
    Q_OBJECT

public:
    explicit MainWindow(QWidget *parent = 0);
    ~MainWindow();

signals:
    void connectWorkers();
    void disconnectWorkers();
    void getParamValue(QString node, QString param);
    void setParamValue(QString node, QString param, float value);
    void getPosAttFromBackend();

private slots:
    void on_pbStart_clicked();

    void on_pbConnect_clicked();

    void on_pbStop_clicked();

    void on_chooseBackend_clicked();

    void updateTracker(float x, float y, float z, float p, float r, float yaw);

    void updatePosAtt();

    void newNodes(QStringList blocks);
    void newParams(QStringList params);
    void newParamValue(QString node, QString param, float val);
    void newConstantBlocks(QStringList blocks);
    void newControlGraph(QString graph);

    void on_paramSelect_currentIndexChanged(const QString &arg1);

    void on_paramValue_returnPressed();

    void on_pbAppendSetpoint_clicked();

    void on_pbNextSetpoint_clicked();

    void sendSetpoints();
    void sendSelectedSetpoint();

    void on_pbActualToSetpoint_clicked();

    void on_pbDeleteSetpoint_clicked();

    void on_pbActualToWaypoint_clicked();

    void on_pbMoveUp_clicked();

    void on_pbMoveDown_clicked();

    void on_pbInsertSetpoint_clicked();

    void on_pbSaveWaypoints_clicked();

    void on_pbLoadWaypoints_clicked();

    void on_socketPath_returnPressed();

    void on_xSetpoint_returnPressed();

    void on_ySetpoint_returnPressed();

    void on_zSetpoint_returnPressed();

private:
    Ui::MainWindow *ui;
    QStandardItemModel * setpointList;
    QTimer * nextSpTimer;
    float sp_x;
    float sp_y;
    float sp_z;
};

#endif // MAINWINDOW_H
